@@ -45,7 +45,7 @@ psutil_kinfo_proc(pid_t pid, struct kinfo_proc *proc) {
 
     size = sizeof(struct kinfo_proc);
     if (sysctl((int *)mib, 4, proc, &size, NULL, 0) == -1) {
-        PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_PID)");
+        psutil_PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_PID)");
         return -1;
     }
 
@@ -83,6 +83,7 @@ psutil_get_proc_list(struct kinfo_proc **procList, size_t *procCount) {
     struct kinfo_proc *buf = NULL;
     int name[] = { CTL_KERN, KERN_PROC, KERN_PROC_PROC, 0 };
     size_t length = 0;
+    size_t max_length = 12 * 1024 * 1024;  // 12MB
 
     assert(procList != NULL);
     assert(*procList == NULL);
@@ -91,24 +92,40 @@ psutil_get_proc_list(struct kinfo_proc **procList, size_t *procCount) {
     // Call sysctl with a NULL buffer in order to get buffer length.
     err = sysctl(name, 3, NULL, &length, NULL, 0);
     if (err == -1) {
-        PyErr_SetFromOSErrnoWithSyscall("sysctl (null buffer)");
+        psutil_PyErr_SetFromOSErrnoWithSyscall("sysctl (null buffer)");
         return 1;
     }
 
-    // Allocate an appropriately sized buffer based on the results
-    // from the previous call.
-    buf = malloc(length);
-    if (buf == NULL) {
-        PyErr_NoMemory();
-        return 1;
-    }
+    while (1) {
+        // Allocate an appropriately sized buffer based on the results
+        // from the previous call.
+        buf = malloc(length);
+        if (buf == NULL) {
+            PyErr_NoMemory();
+            return 1;
+        }
 
-    // Call sysctl again with the new buffer.
-    err = sysctl(name, 3, buf, &length, NULL, 0);
-    if (err == -1) {
-        PyErr_SetFromOSErrnoWithSyscall("sysctl");
-        free(buf);
-        return 1;
+        // Call sysctl again with the new buffer.
+        err = sysctl(name, 3, buf, &length, NULL, 0);
+        if (err == -1) {
+            free(buf);
+            if (errno == ENOMEM) {
+                // Sometimes the first sysctl() suggested size is not enough,
+                // so we dynamically increase it until it's big enough :
+                // https://github.com/giampaolo/psutil/issues/2093
+                psutil_debug("errno=ENOMEM, length=%zu; retrying", length);
+                length *= 2;
+                if (length < max_length) {
+                    continue;
+                }
+            }
+
+            psutil_PyErr_SetFromOSErrnoWithSyscall("sysctl()");
+            return 1;
+        }
+        else {
+            break;
+        }
     }
 
     *procList = buf;
@@ -118,24 +135,24 @@ psutil_get_proc_list(struct kinfo_proc **procList, size_t *procCount) {
 
 
 /*
- * XXX no longer used; it probably makese sense to remove it.
  * Borrowed from psi Python System Information project
- *
- * Get command arguments and environment variables.
- *
  * Based on code from ps.
- *
- * Returns:
- *      0 for success;
- *      -1 for failure (Exception raised);
- *      1 for insufficient privileges.
  */
-static char
-*psutil_get_cmd_args(pid_t pid, size_t *argsize) {
+PyObject *
+psutil_proc_cmdline(PyObject *self, PyObject *args) {
+    pid_t pid;
     int mib[4];
     int argmax;
     size_t size = sizeof(argmax);
     char *procargs = NULL;
+    size_t pos = 0;
+    PyObject *py_retlist = PyList_New(0);
+    PyObject *py_arg = NULL;
+
+    if (py_retlist == NULL)
+        return NULL;
+    if (! PyArg_ParseTuple(args, _Py_PARSE_PID, &pid))
+        goto error;
 
     // Get the maximum process arguments size.
     mib[0] = CTL_KERN;
@@ -143,13 +160,13 @@ static char
 
     size = sizeof(argmax);
     if (sysctl(mib, 2, &argmax, &size, NULL, 0) == -1)
-        return NULL;
+        goto error;
 
     // Allocate space for the arguments.
     procargs = (char *)malloc(argmax);
     if (procargs == NULL) {
         PyErr_NoMemory();
-        return NULL;
+        goto error;
     }
 
     // Make a sysctl() call to get the raw argument space of the process.
@@ -160,55 +177,33 @@ static char
 
     size = argmax;
     if (sysctl(mib, 4, procargs, &size, NULL, 0) == -1) {
-        free(procargs);
-        PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_ARGS)");
-        return NULL;
-    }
-
-    // return string and set the length of arguments
-    *argsize = size;
-    return procargs;
-}
-
-
-// returns the command line as a python list object
-PyObject *
-psutil_get_cmdline(pid_t pid) {
-    char *argstr = NULL;
-    size_t pos = 0;
-    size_t argsize = 0;
-    PyObject *py_retlist = Py_BuildValue("[]");
-    PyObject *py_arg = NULL;
-
-    if (pid < 0)
-        return py_retlist;
-    argstr = psutil_get_cmd_args(pid, &argsize);
-    if (argstr == NULL)
+        psutil_PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_ARGS)");
         goto error;
+    }
 
     // args are returned as a flattened string with \0 separators between
     // arguments add each string to the list then step forward to the next
     // separator
-    if (argsize > 0) {
-        while (pos < argsize) {
-            py_arg = PyUnicode_DecodeFSDefault(&argstr[pos]);
+    if (size > 0) {
+        while (pos < size) {
+            py_arg = PyUnicode_DecodeFSDefault(&procargs[pos]);
             if (!py_arg)
                 goto error;
             if (PyList_Append(py_retlist, py_arg))
                 goto error;
             Py_DECREF(py_arg);
-            pos = pos + strlen(&argstr[pos]) + 1;
+            pos = pos + strlen(&procargs[pos]) + 1;
         }
     }
 
-    free(argstr);
+    free(procargs);
     return py_retlist;
 
 error:
     Py_XDECREF(py_arg);
     Py_DECREF(py_retlist);
-    if (argstr != NULL)
-        free(argstr);
+    if (procargs != NULL)
+        free(procargs);
     return NULL;
 }
 
@@ -243,8 +238,9 @@ psutil_proc_exe(PyObject *self, PyObject *args) {
             return PyUnicode_DecodeFSDefault("");
         }
         else {
-            return \
-                PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_PATHNAME)");
+            return psutil_PyErr_SetFromOSErrnoWithSyscall(
+                "sysctl(KERN_PROC_PATHNAME)"
+            );
         }
     }
     if (size == 0 || strlen(pathname) == 0) {
@@ -305,7 +301,7 @@ psutil_proc_threads(PyObject *self, PyObject *args) {
     size = 0;
     error = sysctl(mib, 4, NULL, &size, NULL, 0);
     if (error == -1) {
-        PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_INC_THREAD)");
+        psutil_PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_INC_THREAD)");
         goto error;
     }
     if (size == 0) {
@@ -321,7 +317,7 @@ psutil_proc_threads(PyObject *self, PyObject *args) {
 
     error = sysctl(mib, 4, kip, &size, NULL, 0);
     if (error == -1) {
-        PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_INC_THREAD)");
+        psutil_PyErr_SetFromOSErrnoWithSyscall("sysctl(KERN_PROC_INC_THREAD)");
         goto error;
     }
     if (size == 0) {
