@@ -1,20 +1,19 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Copyright (c) 2009, Giampaolo Rodola'. All rights reserved.
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
-"""
-Same as bench_oneshot.py but uses perf module instead, which is
+"""Same as bench_oneshot.py but uses perf module instead, which is
 supposed to be more precise.
 """
 
 import sys
 
 import pyperf  # requires "pip install pyperf"
+from bench_oneshot import names
 
 import psutil
-from bench_oneshot import names
 
 
 p = psutil.Process()
@@ -32,17 +31,15 @@ def call_oneshot():
             fun()
 
 
-def add_cmdline_args(cmd, args):
-    cmd.append(args.benchmark)
-
-
 def main():
     runner = pyperf.Runner()
 
     args = runner.parse_args()
     if not args.worker:
-        print("%s methods involved on platform %r (psutil %s):" % (
-            len(names), sys.platform, psutil.__version__))
+        print(
+            "%s methods involved on platform %r (psutil %s):"
+            % (len(names), sys.platform, psutil.__version__)
+        )
         for name in sorted(names):
             print("    " + name)
 
